@@ -10,6 +10,7 @@ import com.sun.speech.freetts.Voice;
 import com.sun.speech.freetts.VoiceManager;
 import com.sun.speech.freetts.Gender;
 import com.sun.speech.freetts.audio.JavaClipAudioPlayer;
+import com.sun.speech.freetts.audio.JavaStreamingAudioPlayer;
 
 public class FreeTTSSynthesisDriver extends UnknownImpl implements SynthesisDriverOperations {
 
@@ -18,8 +19,8 @@ public class FreeTTSSynthesisDriver extends UnknownImpl implements SynthesisDriv
 	private Voice[] voices = null;
 	private int index = 0;
 	private SpeechThread thread = null;
-	
-	
+
+
 	public void bonoboActivate (String iid, String [] args) {
 		ORB orb = AccessUtil.getORB ();
 		String ior = orb.object_to_string (tie._this_object());
@@ -99,8 +100,6 @@ public class FreeTTSSynthesisDriver extends UnknownImpl implements SynthesisDriv
 	    int index = specLocale.indexOf ('_');
 	    Locale locale = voice.getLocale ();
 
-	    System.out.println (specLocale);
-
 	    // TODO: should we just use String.matches (Regexp) here instead ?
 
 	    if (index > 0) lang = specLocale.substring (0, index); 
@@ -115,7 +114,8 @@ public class FreeTTSSynthesisDriver extends UnknownImpl implements SynthesisDriv
 			return false; // For now, FreeTTS doesn't have any locales with encoding suffices
 		    }
 		}
-		if ((country == null) || (voiceCountry == null) || (voiceCountry.length () == 0) || 
+		if ((country == null) || (voiceCountry == null) || 
+		    (voiceCountry.length () == 0) || 
 		    voiceCountry.toUpperCase().equals (country)) 
 		    return true;
 	    }
@@ -129,19 +129,14 @@ public class FreeTTSSynthesisDriver extends UnknownImpl implements SynthesisDriv
 		VoiceInfo vi = null;
 		VoiceInfo via[];
 
-		System.err.println ("getVoices...");
-
-		System.err.println ("spec name=" + voice_spec.name + " lang=" + voice_spec.language);
-
 		if (voices == null)
 			voices = vm.getVoices ();
+
 		num_voices = voices.length;
 		for (i = 0; i < num_voices; i++)
 		{
 			vi = getVoiceInfo (voices[i]);
 
-		    System.err.println ("checking voice " + i + " " + vi.name);
-			
 			// If the name isn't empty and doesn't match, skip this one
 
 			if (!voices[i].getDomain().equals("general"))
@@ -155,7 +150,6 @@ public class FreeTTSSynthesisDriver extends UnknownImpl implements SynthesisDriv
                              // would test gender_unspecified, but API freeze blocks addition to enum...
 			    voice_spec.gender != vi.gender)
 				continue;
-			System.err.println ("adding speaker " + vi.name);
 			matched.add (vi);
 		}
 		num_voices = matched.size ();
@@ -173,8 +167,6 @@ public class FreeTTSSynthesisDriver extends UnknownImpl implements SynthesisDriv
 		VoiceInfo[] vi;
 		Vector list = new Vector ();
 
-		System.out.println ("getAllVoices...");
-
 		if (voices == null)
 			voices = vm.getVoices ();
 
@@ -216,11 +208,12 @@ public class FreeTTSSynthesisDriver extends UnknownImpl implements SynthesisDriv
 			if (voice_spec.language.length () != 0 && !voice_spec.language.equals(vi.language))
 				continue;
 			
-			System.out.println ("Found voice.");
 			if (!voices[i].isLoaded ())
 			{
-				System.out.println ("Loading voice.");
-				voices[i].setAudioPlayer (new JavaClipAudioPlayer());
+				if (System.getProperty("ft_audio_player") == "streaming")
+					voices[i].setAudioPlayer (new JavaStreamingAudioPlayer());
+				else
+					voices[i].setAudioPlayer (new JavaClipAudioPlayer());
 				voices[i].allocate ();
 			}
 			speaker = SpeakerHelper.narrow ((new FreeTTSSpeaker (this, voices[i])).tie());
@@ -276,24 +269,25 @@ public class FreeTTSSynthesisDriver extends UnknownImpl implements SynthesisDriv
 		private boolean done = false;
 		private Vector SpeechQueue = null;
 		private QueueEntry current = null;
-	
+  	        private boolean debug = Boolean.getBoolean("debug");
+
 		public SpeechThread () {
 			SpeechQueue = new Vector ();
 		}
 	
 		public void run () {
-			current = null;
 			while (done == false) {
 				synchronized (SpeechQueue) {
+				        current = null;
 					if (SpeechQueue.size() == 0) {
 						try {
 							SpeechQueue.wait ();
 						} catch (InterruptedException ie) {
 						}
 					}
-				}
-				synchronized (SpeechQueue) {
-					current = (QueueEntry) SpeechQueue.remove(0);
+					if (SpeechQueue.size() > 0) {
+					        current = (QueueEntry) SpeechQueue.remove(0);
+					}
 				}
 				if (current != null) {
 					
@@ -312,8 +306,11 @@ public class FreeTTSSynthesisDriver extends UnknownImpl implements SynthesisDriv
 							System.err.println ("error: " + ex);
 						}
 
-					System.out.println ("speaking " + current.text);
+					if (debug) {
+ 					        System.out.println("Speaking: " + current.text);
+					}
 					current.s.v.speak (current.text);
+
 					if (current.s.getCallback() != null)
 						try {
 							current.s.getCallback()._notify (speech_callback_type.speech_callback_speech_ended,
@@ -342,8 +339,10 @@ public class FreeTTSSynthesisDriver extends UnknownImpl implements SynthesisDriv
 		}
 
 		public synchronized void removeAll () {
-			current.s.v.getAudioPlayer().cancel();
 			synchronized (SpeechQueue) {
+			        if (current != null) {
+			                current.s.v.getAudioPlayer().cancel();
+                                }
 				SpeechQueue.removeAllElements();
 			}
 		}
