@@ -23,6 +23,7 @@
  */
 
 #include <stdio.h>
+#include <string.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -87,7 +88,7 @@ select_server (CORBA_Environment *ev)
 	fgets (input, 80, stdin);
 	i = atoi (input);
 	i--;
-	if (i < 0 || i > servers->_length)
+	if (i < 0 || i >= servers->_length)
 	{
 		printf ("Server not found.\n");
 		CORBA_free (servers);
@@ -338,6 +339,7 @@ do_test (GNOME_Speech_SynthesisDriver driver, CORBA_Environment *ev)
 	speaker_say_print (speaker, "2. Callback test.\n");
 	speaker_say_print (speaker, "3. Speech Interrupt test.\n");
 	speaker_say_print (speaker, "4. Wait test.\n");
+	speaker_say_print (speaker, "5. UTF-8 test.\n");
 	speaker_say_print (speaker, "0. Exit.\n");
 	printf ("\nSelect test: ");
 	fgets (input, 80, stdin);
@@ -362,6 +364,10 @@ do_test (GNOME_Speech_SynthesisDriver driver, CORBA_Environment *ev)
 		GNOME_Speech_Speaker_stop (speaker, ev);
 		wait_test (speaker);
 		break;
+	case 5:
+		GNOME_Speech_Speaker_stop (speaker, ev);
+		GNOME_Speech_Speaker_say (speaker, "£ € ø µ æ ß ¢ ", ev);
+		break;
 	case 0:
 		GNOME_Speech_Speaker_stop (speaker, ev);
 		GNOME_Speech_Speaker_say (speaker, "Goodbye.", ev);
